package sun.security.provider.certpath;

import java.io.IOException;
import java.util.Iterator;
import sun.misc.HexDumpEncoder;
import sun.security.util.DerValue;
import sun.security.x509.PKIXExtensions;
import sun.security.util.DerOutputStream;
import java.util.Collections;
import java.security.cert.Extension;
import java.util.List;
import sun.security.util.Debug;

class OCSPRequest
{
    private static final Debug debug;
    private static final boolean dump;
    private final List<CertId> certIds;
    private final List<Extension> extensions;
    private byte[] nonce;
    
    OCSPRequest(CertId o) {
        this(Collections.singletonList(o));
    }
    
    OCSPRequest(List<CertId> certIds) {
        this.certIds = certIds;
        this.extensions = Collections.emptyList();
    }
    
    OCSPRequest(List<CertId> certIds, List<Extension> extensions) {
        this.certIds = certIds;
        this.extensions = extensions;
    }
    
    byte[] encodeBytes() throws IOException {
        DerOutputStream derOutputStream = new DerOutputStream();
        DerOutputStream derOutputStream2 = new DerOutputStream();
        for (CertId certId : this.certIds) {
            DerOutputStream o = new DerOutputStream();
            certId.encode(o);
            derOutputStream2.write((byte)48, o);
        }
        derOutputStream.write((byte)48, derOutputStream2);
        if (!this.extensions.isEmpty()) {
            DerOutputStream o2 = new DerOutputStream();
            for (Extension extension : this.extensions) {
                extension.encode(o2);
                if (extension.getId().equals(PKIXExtensions.OCSPNonce_Id.toString())) {
                    this.nonce = extension.getValue();
                }
                else {
                    continue;
                }
            }
            DerOutputStream o3 = new DerOutputStream();
            o3.write((byte)48, o2);
            derOutputStream.write(DerValue.createTag((byte)(-128), true, (byte)2), o3);
        }
        DerOutputStream o4 = new DerOutputStream();
        o4.write((byte)48, derOutputStream);
        DerOutputStream o5 = new DerOutputStream();
        o5.write((byte)48, o4);
        byte[] byteArray = o5.toByteArray();
        if (OCSPRequest.dump) {
            OCSPRequest.debug.println("OCSPRequest bytes...\n\n" + new HexDumpEncoder().encode(byteArray) + "\n");
            return byteArray;
        }
        return byteArray;
    }
    
    List<CertId> getCertIds() {
        return this.certIds;
    }
    
    byte[] getNonce() {
        return this.nonce;
    }
    
    static {
        debug = Debug.getInstance("certpath");
        dump = (OCSPRequest.debug != null && Debug.isOn("ocsp"));
    }
}
